@@ -5,10 +5,11 @@ from oardocker.actions import execute
 
 @click.command('exec')
 @click.option('-l', '--user', default="docker")
+@click.option('-w', '--workdir', default="~")
 @click.argument('hostname', required=True)
 @click.argument('cmd', nargs=-1)
 @pass_state
 @pass_context
-def cli(ctx, state, user, hostname, cmd):
+def cli(ctx, state, user, workdir, hostname, cmd):
     """Run a command in an existing node."""
-    execute(ctx, state, user, hostname, cmd)
+    execute(ctx, state, user, hostname, cmd, workdir)
